agendas() is the container for all implementations of a procedure.
Requires exactly one baseline() and accepts any number of named
variant() objects.
Arguments
- base
A
baseline()object. Required.- ...
Named
variant()objects.
agendas() is the container for all implementations of a procedure.
Requires exactly one baseline() and accepts any number of named
variant() objects.
A baseline() object. Required.
Named variant() objects.