Skip to contents

HTEST_FN() is a developer-interface constructor for user-facing test functions like TTEST(). It returns a function with a consistent signature that routes to the correct implementation based on the variable mapper <var_id> and method variant.

Usage

HTEST_FN(cls, defs, .name)

Arguments

cls

A string naming the test class, e.g. "ttest".

defs

A list of stat_define() objects.

.name

A string used as the test title in output.

Value

A function with signature function(.var_id, .data, ...).