HTEST_FN() is a developer-interface constructor for user-facing test
functions like TTEST(). It returns a function with a consistent
signature that routes to the correct implementation based on the variable mapper <var_id>
and method variant.
Arguments
- cls
A string naming the test class, e.g.
"ttest".- defs
A list of
stat_define()objects.- .name
A string used as the test title in output.