var_id is the abstract parent class for all Variable Mapper objects in
{statim}. Variable Mappers emulate R's formula interface, as they capture
variable expressions without evaluating them, describing the structure
of a statistical model to be passed into a pipeline.
Details
Concrete subclasses include x_by(), rel(), and pairwise(). You
cannot instantiate var_id directly; use one of its subclasses.